Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/batchprocessing.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/batchprocessing.txt	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/batchprocessing.txt	(revision 11954)
@@ -21,6 +21,6 @@
 Create a site:
 
-    >>> from waeup.ikoba.app import Institution
-    >>> getRootFolder()['app'] = Institution()
+    >>> from waeup.ikoba.app import Company
+    >>> getRootFolder()['app'] = Company()
     >>> from zope.component.hooks import setSite
     >>> setSite(getRootFolder()['app'])
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/breadcrumbs.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/breadcrumbs.txt	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/breadcrumbs.txt	(revision 11954)
@@ -9,9 +9,9 @@
 ===============================
 
-We create a institution to check the breadcrumb functionality.
-
-    >>> from waeup.ikoba.app import Institution
+We create a company to check the breadcrumb functionality.
+
+    >>> from waeup.ikoba.app import Company
     >>> root = getRootFolder()
-    >>> root['app'] = Institution()
+    >>> root['app'] = Company()
     >>> app = root['app']
 
@@ -25,5 +25,5 @@
     >>> blist1 = getBreadcrumbList(app, 'index')
     >>> blist1
-    [<waeup.ikoba.browser.breadcrumbs.InstitutionBreadcrumb object at 0x...>]
+    [<waeup.ikoba.browser.breadcrumbs.CompanyBreadcrumb object at 0x...>]
 
 A slightly more extensive list for the datacenter:
@@ -32,9 +32,9 @@
     >>> from pprint import pprint
     >>> pprint(blist2)
-    [<waeup.ikoba.browser.breadcrumbs.InstitutionBreadcrumb object at 0x...>,
+    [<waeup.ikoba.browser.breadcrumbs.CompanyBreadcrumb object at 0x...>,
      <waeup.ikoba.browser.breadcrumbs.AdministrationBreadcrumb object at 0x...>,
      <waeup.ikoba.browser.breadcrumbs.DataCenterBreadcrumb object at 0x...>]
 
-We get a breadcrumb for institution, administration area and data
+We get a breadcrumb for company, administration area and data
 center in that order.
 
@@ -47,11 +47,11 @@
 
      >>> pprint([(x.context, x.viewname) for x in blist2])
-     [(<waeup.ikoba.app.Institution object at 0x...>, 'index'),
-      (<waeup.ikoba.app.Institution object at 0x...>, 'administration'),
+     [(<waeup.ikoba.app.Company object at 0x...>, 'index'),
+      (<waeup.ikoba.app.Company object at 0x...>, 'administration'),
       (<waeup.ikoba.datacenter.DataCenter object at 0x...>, 'index')]
 
 The administration area breadcrumb might be a surprise, as there is no
 equivalent object in the ZODB. In fact the administration area is only
-a certain view (the 'administration' view) on the institution object.
+a certain view (the 'administration' view) on the company object.
 
 We will show below, how you can define breadcrumbs this way.
@@ -62,5 +62,5 @@
 
 This way we can make sure, that there are different breadcrumb lists
-generated for instance for the administration view of Institution
+generated for instance for the administration view of Company
 instances and the index view. While the first should look something
 like::
@@ -118,5 +118,5 @@
 
     >>> pprint(mybccontainer.getList())
-    [<...breadcrumbs.InstitutionBreadcrumb object at 0x...>,
+    [<...breadcrumbs.CompanyBreadcrumb object at 0x...>,
      <...breadcrumbs.AdministrationBreadcrumb object at 0x...>,
      <...breadcrumbs.UsersContainerBreadcrumb object at 0x...>]
@@ -128,5 +128,5 @@
 
 Now we can get breadcrumbs for contexts and view names. For example a
-breadcrumb for the 'index' view of our Institution object:
+breadcrumb for the 'index' view of our Company object:
 
     >>> from zope.component import getAdapter
@@ -134,5 +134,5 @@
     >>> b1 = getAdapter(app, IBreadcrumb, 'index')
     >>> b1
-    <waeup.ikoba.browser.breadcrumbs.InstitutionBreadcrumb object at 0x...>
+    <waeup.ikoba.browser.breadcrumbs.CompanyBreadcrumb object at 0x...>
 
 Breadcrumb objects provide a title:
@@ -168,7 +168,7 @@
 
     >>> b2.parent
-    (<waeup.ikoba.app.Institution object at 0x...>, 'administration')
-
-This result denotes a new context object (the Institution instance we
+    (<waeup.ikoba.app.Company object at 0x...>, 'administration')
+
+This result denotes a new context object (the Company instance we
 created above) and a view name ('administration').
 
@@ -188,5 +188,5 @@
 As you can see, we get an AdministrationBreadcrumb, although the
 context object, for which the breadcrumb was created is also the
-Institution instance as above:
+Company instance as above:
 
     >>> b3.context is b1.context
@@ -197,5 +197,5 @@
     >>> context, viewname = b3.parent
     >>> context, viewname
-    (<waeup.ikoba.app.Institution object at 0x...>, 'index')
+    (<waeup.ikoba.app.Company object at 0x...>, 'index')
 
 We create last breadcrumb:
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/browser.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/browser.txt	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/browser.txt	(revision 11954)
@@ -4,10 +4,10 @@
 Here we visit all parts of a Ikoba portal using a browser.
 
-Institution
+Company
 ==========
 
 We can watch universities in the browser.
 
-We create an institution object and put into the ZODB root::
+We create an company object and put into the ZODB root::
 
   >>> root = getRootFolder()
@@ -15,12 +15,12 @@
   []
 
-  >>> from waeup.ikoba.app import Institution
-  >>> u = Institution()
-  >>> root['myinstitution'] = u
+  >>> from waeup.ikoba.app import Company
+  >>> u = Company()
+  >>> root['mycompany'] = u
   >>> list(root)
-  [u'myinstitution']
+  [u'mycompany']
 
   >>> from zope.component.hooks import setSite
-  >>> setSite(root['myinstitution'])
+  >>> setSite(root['mycompany'])
 
 To make sure, we can 'watch' pages, we first have to initialize out
@@ -30,7 +30,7 @@
   >>> browser = Browser()
 
-Let's get the default view of a institution::
-
-  >>> browser.open('http://localhost/myinstitution')
+Let's get the default view of a company::
+
+  >>> browser.open('http://localhost/mycompany')
   >>> print browser.contents
   <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
@@ -55,5 +55,5 @@
 The contact form for anonymous users is called 'Enquiries'::
 
-  >>> browser.open('http://localhost/myinstitution')
+  >>> browser.open('http://localhost/mycompany')
   >>> browser.getLink('Enquiries').click()
   >>> browser.getControl('Send').click()
@@ -74,7 +74,7 @@
 Registered users with an email address can request a password change:
 
-  >>> root['myinstitution']['users'].addUser('forgetful', 'secret',title='Bob Forgetful',
+  >>> root['mycompany']['users'].addUser('forgetful', 'secret',title='Bob Forgetful',
   ...                               description='A forgetful user', email='aa@aa.ng')
-  >>> browser.open('http://localhost/myinstitution/changepw')
+  >>> browser.open('http://localhost/mycompany/changepw')
   >>> browser.getControl(name="form.identifier").value = 'forgetful'
   >>> browser.getControl(name="form.email").value = 'aa@aa.ng'
@@ -91,13 +91,13 @@
 We can then get an edit view of the configuration container::
 
-  >>> browser.open('http://localhost/myinstitution/configuration')
-  >>> print browser.contents
-  <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
-  ...<form action="http://localhost/myinstitution/configuration/@@index"
-  ...
-
-The edit form contains the default value for the institution name::
-
-  >>> 'Sample Institution' in browser.contents
+  >>> browser.open('http://localhost/mycompany/configuration')
+  >>> print browser.contents
+  <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
+  ...<form action="http://localhost/mycompany/configuration/@@index"
+  ...
+
+The edit form contains the default value for the company name::
+
+  >>> 'Sample Company' in browser.contents
   True
 
@@ -110,5 +110,5 @@
   ...
 
-  >>> browser.open('http://localhost/myinstitution/configuration')
+  >>> browser.open('http://localhost/mycompany/configuration')
   >>> browser.getControl("Update plugins").click()
   >>> print browser.contents
@@ -120,5 +120,5 @@
 and is properly rendered on the frontpage of the portal:
 
-  >>> browser.open('http://localhost/myinstitution')
+  >>> browser.open('http://localhost/mycompany')
   >>> print browser.contents
   <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
@@ -134,5 +134,5 @@
 If we change to German so that the German part of frontpage.rst is rendered:
 
-  >>> browser.open('http://localhost/myinstitution//@@change_language?lang=de')
+  >>> browser.open('http://localhost/mycompany//@@change_language?lang=de')
   >>> print browser.contents
   <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
@@ -147,5 +147,5 @@
 Switch back to English:
 
-  >>> browser.open('http://localhost/myinstitution//@@change_language?lang=en')
+  >>> browser.open('http://localhost/mycompany//@@change_language?lang=en')
 
 
@@ -153,5 +153,5 @@
 ============
 
-  >>> browser.open('http://localhost/myinstitution')
+  >>> browser.open('http://localhost/mycompany')
   >>> browser.getLink('Portal Users').click()
   >>> print browser.contents
@@ -187,10 +187,10 @@
 manually by setting the roles attribute:
 
-  >>> print root['myinstitution']['users']['bob'].roles
+  >>> print root['mycompany']['users']['bob'].roles
   []
-  >>> root['myinstitution']['users']['bob'].roles = ['waeup.UsersManager']
-  >>> print root['myinstitution']['users']['bob'].roles
+  >>> root['mycompany']['users']['bob'].roles = ['waeup.UsersManager']
+  >>> print root['mycompany']['users']['bob'].roles
   ['waeup.UsersManager']
-  >>> browser.open('http://localhost/myinstitution/users')
+  >>> browser.open('http://localhost/mycompany/users')
   >>> print browser.contents
   <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
@@ -200,5 +200,5 @@
 Users can't be added twice:
 
-  >>> browser.open('http://localhost/myinstitution/users/add')
+  >>> browser.open('http://localhost/mycompany/users/add')
   >>> browser.getControl(name="form.name").value = 'bob'
   >>> browser.getControl(name="form.title").value = 'Bob The User'
@@ -215,5 +215,5 @@
 Users can be deleted:
 
-  >>> browser.open('http://localhost/myinstitution/users')
+  >>> browser.open('http://localhost/mycompany/users')
   >>> browser.getControl("Remove", index=0).click()
   >>> 'User account bob successfully deleted' in browser.contents
@@ -227,5 +227,5 @@
 Let's enter the contact form::
 
-  >>> browser.open('http://localhost/myinstitution/contactadmin')
+  >>> browser.open('http://localhost/mycompany/contactadmin')
   >>> print browser.contents
   <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
@@ -236,5 +236,5 @@
 contact@waeup.org)::
 
-  >>> browser.open('http://localhost/myinstitution/contactadmin')
+  >>> browser.open('http://localhost/mycompany/contactadmin')
   >>> browser.getControl(name='form.body').value = "test message"
   >>> browser.getControl('Send').click()
@@ -253,5 +253,5 @@
 The data center helps us uploading files for later import or similar.
 
-  >>> browser.open('http://localhost/myinstitution')
+  >>> browser.open('http://localhost/mycompany')
   >>> browser.getLink('Data Center').click()
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/captcha.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/captcha.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/captcha.py	(revision 11954)
@@ -32,5 +32,5 @@
     ICaptchaRequest, ICaptchaResponse, ICaptcha, ICaptchaConfig,
     ICaptchaManager)
-from waeup.ikoba.interfaces import IInstitution
+from waeup.ikoba.interfaces import ICompany
 
 #
@@ -322,5 +322,5 @@
     # A test page to see a captcha in action
     grok.name('captcha')
-    grok.context(IInstitution)
+    grok.context(ICompany)
     grok.require('waeup.Public')
     title = 'Captcha Test'
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/exceptions.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/exceptions.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/exceptions.py	(revision 11954)
@@ -64,5 +64,5 @@
     """A page rendered when an object cannot be found.
 
-    XXX: This page won't work for objects above a w.k.Institution.
+    XXX: This page won't work for objects above a w.k.Company.
     """
     grok.context(INotFound)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/interfaces.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/interfaces.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/interfaces.py	(revision 11954)
@@ -21,5 +21,5 @@
 from zope.interface import Interface, Attribute
 from waeup.ikoba.interfaces import (
-    IIkobaObject, IInstitution, IUsersContainer, IDataCenter, validate_email)
+    IIkobaObject, ICompany, IUsersContainer, IDataCenter, validate_email)
 from waeup.ikoba.interfaces import MessageFactory as _
 
@@ -161,5 +161,5 @@
 
         If no `headerline` is given, a default will be rendered (name
-        of institution).
+        of company).
 
         If no `title` is given, nothing will be rendered.
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/layout.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/layout.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/layout.py	(revision 11954)
@@ -227,5 +227,5 @@
 
     def getAppTitle(self):
-        return getattr(grok.getSite()['configuration'], 'name', u'Sample Institution')
+        return getattr(grok.getSite()['configuration'], 'name', u'Sample Company')
 
     def getAppAcronym(self):
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/pdf.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/pdf.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/pdf.py	(revision 11954)
@@ -710,5 +710,5 @@
             doc, 'ikoba_headtitle', getattr(
                 site_config, 'name',
-                u'Sample Institution'))
+                u'Sample Company'))
         canvas.setFont("Helvetica-Bold", 18)
         if self.header_logo_left_path is not None:
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/companypage.pt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/companypage.pt	(revision 11954)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/companypage.pt	(revision 11954)
@@ -0,0 +1,1 @@
+<span tal:replace="structure view/frontpage">Frontpage</span>
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/companyrss20feed.pt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/companyrss20feed.pt	(revision 11954)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/companyrss20feed.pt	(revision 11954)
@@ -0,0 +1,59 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<rss version="2.0"
+     xmlns:tal="http://xml.zope.org/namespaces/tal"
+     xmlns:atom="http://www.w3.org/2005/Atom">
+  <channel>
+    <title>
+      <tal:block tal:content="view/title"/>
+      <tal:block
+	  tal:define="title view/contexttitle"
+	  tal:condition="title"> - <tal:block content="title"/>
+      </tal:block>
+    </title>
+    <link
+	tal:content="view/link"></link>
+    <description
+	tal:content="view/description"></description>
+    <language
+	tal:condition="view/language"
+	tal:content="view/language"></language>
+    <pubDate
+	tal:condition="view/date"
+	tal:content="view/date"></pubDate>
+    <lastBuildDate
+	tal:condition="view/buildDate"
+	tal:content="view/buildDate"></lastBuildDate>
+    <managingEditor
+	tal:condition="view/editor"
+	tal:content="view/editor"></managingEditor>
+    <webMaster
+	tal:condition="view/webmaster"
+	tal:content="view/webmaster"></webMaster>
+    <atom:link
+	tal:attributes="href string:${view/link}@@feeds/${view/name}"
+	rel="self" type="application/rss+xml" />
+    <item
+	tal:repeat="item view/entries">
+      <title
+	  tal:content="item/title"></title>
+      <description
+	  tal:content="item/description"></description>
+      <guid
+	  tal:content="item/guid"
+	  tal:define="isPermaLink item/isPermaLink|nothing"
+	  tal:attributes="isPermaLink python:isPermaLink and 'true' or 'false'"></guid>
+      <link
+	  tal:condition="item/link|nothing"
+	  tal:content="item/link"></link>
+      <author
+	  tal:condition="item/author|nothing"
+	  tal:content="item/author"></author>
+      <category
+	  tal:condition="item/category|nothing"
+	  tal:content="item/category"></category>
+      <pubDate
+	  tal:condition="item/pubDate|nothing"
+	  tal:content="item/pubDate"></pubDate>
+    </item>
+  </channel>
+</rss>
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/institutionpage.pt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/institutionpage.pt	(revision 11952)
+++ 	(revision )
@@ -1,1 +1,0 @@
-<span tal:replace="structure view/frontpage">Frontpage</span>
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/institutionrss20feed.pt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/institutionrss20feed.pt	(revision 11952)
+++ 	(revision )
@@ -1,59 +1,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<rss version="2.0"
-     xmlns:tal="http://xml.zope.org/namespaces/tal"
-     xmlns:atom="http://www.w3.org/2005/Atom">
-  <channel>
-    <title>
-      <tal:block tal:content="view/title"/>
-      <tal:block
-	  tal:define="title view/contexttitle"
-	  tal:condition="title"> - <tal:block content="title"/>
-      </tal:block>
-    </title>
-    <link
-	tal:content="view/link"></link>
-    <description
-	tal:content="view/description"></description>
-    <language
-	tal:condition="view/language"
-	tal:content="view/language"></language>
-    <pubDate
-	tal:condition="view/date"
-	tal:content="view/date"></pubDate>
-    <lastBuildDate
-	tal:condition="view/buildDate"
-	tal:content="view/buildDate"></lastBuildDate>
-    <managingEditor
-	tal:condition="view/editor"
-	tal:content="view/editor"></managingEditor>
-    <webMaster
-	tal:condition="view/webmaster"
-	tal:content="view/webmaster"></webMaster>
-    <atom:link
-	tal:attributes="href string:${view/link}@@feeds/${view/name}"
-	rel="self" type="application/rss+xml" />
-    <item
-	tal:repeat="item view/entries">
-      <title
-	  tal:content="item/title"></title>
-      <description
-	  tal:content="item/description"></description>
-      <guid
-	  tal:content="item/guid"
-	  tal:define="isPermaLink item/isPermaLink|nothing"
-	  tal:attributes="isPermaLink python:isPermaLink and 'true' or 'false'"></guid>
-      <link
-	  tal:condition="item/link|nothing"
-	  tal:content="item/link"></link>
-      <author
-	  tal:condition="item/author|nothing"
-	  tal:content="item/author"></author>
-      <category
-	  tal:condition="item/category|nothing"
-	  tal:content="item/category"></category>
-      <pubDate
-	  tal:condition="item/pubDate|nothing"
-	  tal:content="item/pubDate"></pubDate>
-    </item>
-  </channel>
-</rss>
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/tests/test_async.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/tests/test_async.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/tests/test_async.py	(revision 11954)
@@ -8,5 +8,5 @@
 from zope.security.interfaces import Unauthorized
 from zope.testbrowser.testing import Browser
-from waeup.ikoba.app import Institution
+from waeup.ikoba.app import Company
 from waeup.ikoba.async import AsyncJob, get_job_id
 from waeup.ikoba.interfaces import IJobManager
@@ -29,5 +29,5 @@
         self.storage = os.path.join(self.workdir, 'storage')
         os.mkdir(self.storage)
-        app = Institution()
+        app = Company()
         app['datacenter'].setStoragePath(self.storage)
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/viewlets.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/viewlets.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/viewlets.py	(revision 11954)
@@ -24,8 +24,8 @@
 from zope.traversing.browser import absoluteURL
 from waeup.ikoba.browser.pages import (
-    InstitutionPage, DatacenterPage,
+    CompanyPage, DatacenterPage,
     UsersContainerPage, UserManageFormPage)
 from waeup.ikoba.browser.interfaces import (
-    IBreadcrumbContainer, IInstitution, IUsersContainer)
+    IBreadcrumbContainer, ICompany, IUsersContainer)
 from waeup.ikoba.interfaces import (
     IIkobaUtils, IIkobaObject, IIkobaXMLExporter,

Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/breadcrumbs.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/breadcrumbs.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/breadcrumbs.py	(revision 11954)
@@ -28,5 +28,5 @@
 from waeup.ikoba.browser.interfaces import (
     IBreadcrumb, IBreadcrumbIgnorable, IBreadcrumbContainer, IIkobaObject,
-    IInstitution, IUsersContainer, IDataCenter,
+    ICompany, IUsersContainer, IDataCenter,
     )
 from waeup.ikoba.reports import IReportsContainer
@@ -86,8 +86,8 @@
         return self.viewname
 
-class InstitutionBreadcrumb(Breadcrumb):
-    """A breadcrumb for institution index pages.
-    """
-    grok.context(IInstitution)
+class CompanyBreadcrumb(Breadcrumb):
+    """A breadcrumb for company index pages.
+    """
+    grok.context(ICompany)
     title = _(u'Home')
     parent = None
@@ -97,10 +97,10 @@
 
     Here we need a special `parent()` implementation, because the
     parent object is not a real parent (the Institution object has no
     valid parent in terms of breadcrumbs). Instead it is the
     ``administration`` view of the same context the ``manage`` page
     itself is bound to.
     """
-    grok.context(IInstitution)
+    grok.context(ICompany)
     grok.name('manage')
     title = _(u'Portal Settings')
@@ -113,7 +113,7 @@
 
 class AdministrationBreadcrumb(Breadcrumb):
-    """A breadcrumb for administration areas of Institution instances.
-    """
-    grok.context(IInstitution)
+    """A breadcrumb for administration areas of Company instances.
+    """
+    grok.context(ICompany)
     grok.name('administration')
     title = _(u'Administration')
@@ -97,10 +97,10 @@
 
     Here we need a special `parent()` implementation, because the
-    parent object is not a real parent (the Institution object has no
+    parent object is not a real parent (the Company object has no
     valid parent in terms of breadcrumbs). Instead it is the
     ``administration`` view of the same context the ``manage`` page
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/pages.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/pages.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/pages.py	(revision 11954)
@@ -46,5 +46,5 @@
     IkobaDisplayFormPage, NullValidator)
 from waeup.ikoba.browser.interfaces import (
-    IInstitution, ICaptchaManager, IChangePassword)
+    ICompany, ICaptchaManager, IChangePassword)
 from waeup.ikoba.browser.layout import jsaction, action, UtilityView
 from waeup.ikoba.interfaces import MessageFactory as _
@@ -325,5 +325,5 @@
 class ContactAdminForm(IkobaForm):
     grok.name('contactadmin')
-    #grok.context(IInstitution)
+    #grok.context(ICompany)
     grok.template('contactform')
     grok.require('waeup.Authenticated')
@@ -405,13 +405,13 @@
 
 #
 # Institution related pages...
 #
 
-class InstitutionPage(IkobaDisplayFormPage):
-    """ The main institution page.
+class CompanyPage(IkobaDisplayFormPage):
+    """ The main company page.
     """
     grok.require('waeup.Public')
     grok.name('index')
-    grok.context(IInstitution)
+    grok.context(ICompany)
     pnav = 0
     label = ''
@@ -434,5 +434,5 @@
     """
     grok.name('administration')
-    grok.context(IInstitution)
+    grok.context(ICompany)
     grok.require('waeup.managePortal')
     label = _(u'Administration')
@@ -443,7 +443,7 @@
     """
     grok.name('feed.rss')
-    grok.context(IInstitution)
+    grok.context(ICompany)
     grok.require('waeup.Public')
-    grok.template('institutionrss20feed')
+    grok.template('companyrss20feed')
 
     name = 'General news feed'
@@ -457,5 +457,5 @@
     @property
     def title(self):
-        return getattr(grok.getSite(), 'name', u'Sample Institution')
+        return getattr(grok.getSite(), 'name', u'Sample Company')
 
     @property
@@ -1568,5 +1568,5 @@
     """Captcha'd page for all kind of users to request a password change.
     """
-    grok.context(IInstitution)
+    grok.context(ICompany)
     grok.name('changepw')
     grok.require('waeup.Anonymous')
@@ -405,13 +405,13 @@
 
 #
-# Institution related pages...
+# Company related pages...
 #
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/tests/test_permissions.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/tests/test_permissions.py	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/tests/test_permissions.py	(revision 11954)
@@ -31,5 +31,5 @@
 from zope.security.interfaces import Unauthorized
 from zope.testbrowser.testing import Browser
-from waeup.ikoba.app import Institution
+from waeup.ikoba.app import Company
 from waeup.ikoba.testing import (
     FunctionalLayer, FunctionalTestCase, get_all_loggers, remove_new_loggers,
@@ -58,6 +58,6 @@
     def setUp(self):
         super(PermissionTest, self).setUp()
-        # Set up a complete institution to have every page available...
-        app = Institution()
+        # Set up a complete company to have every page available...
+        app = Company()
         self.getRootFolder()['app'] = app
         setSite(self.getRootFolder()['app'])